@@ -83,9 +83,9 @@ def get_notifications(
     +----------+----------------+------------------------------------------------------------------+
     | ``"t2"`` | :py:obj:`int`  | End of interval 2 (minutes from midnight)                        |
     +----------+----------------+------------------------------------------------------------------+
-    | ``"m"``  | :py:obj:`int`  | Mask of the days of the month (1: 2:\ sup:`0`, 31: 2\ :sup:`30`) |
+    | ``"m"``  | :py:obj:`int`  | Mask of the days of the month (1: 2\ :sup:`0`, 31: 2\ :sup:`30`) |
     +----------+----------------+------------------------------------------------------------------+
-    | ``"y"``  | :py:obj:`int`  | Mask of months (Jan: 2\ :sup:`0`, Dec: 2:\ sup:`11`)             |
+    | ``"y"``  | :py:obj:`int`  | Mask of months (Jan: 2\ :sup:`0`, Dec: 2\ :sup:`11`)             |
     +----------+----------------+------------------------------------------------------------------+
     | ``"w"``  | :py:obj:`int`  | Mask of days of the week (Mon: 2\ :sup:`0`, Sun: 2\ :sup:`6`)    |
     +----------+----------------+------------------------------------------------------------------+
